@@ -1,4 +1,5 @@
 import os
+
 import twine.settings as settings
 
 
@@ -17,6 +18,7 @@ def default(hub):
     """
     return {
         "settings": settings.Settings(
-            non_interactive=True, config_file=os.path.expanduser("~/.pypirc"),
+            non_interactive=True,
+            config_file=os.path.expanduser("~/.pypirc"),
         )
     }
