@@ -1,7 +1,3 @@
-import twine.settings as settings
-import os
-
-
 def pre(hub, ctx):
     func_ctx = ctx.get_arguments().get("ctx")
     if func_ctx and not func_ctx.acct:
