@@ -1,7 +1,6 @@
-# Import python libs
 import pathlib
-import subprocess
 import shutil
+import subprocess
 import sys
 
 
@@ -10,7 +9,13 @@ def clean(hub, root_dir: pathlib.Path):
     clean everything up
     """
     ret = subprocess.run(
-        [sys.executable, str(root_dir / "setup.py"), "--no-user-cfg", "--quiet", "clean"]
+        [
+            sys.executable,
+            str(root_dir / "setup.py"),
+            "--no-user-cfg",
+            "--quiet",
+            "clean",
+        ]
     )
     ret.check_returncode()
     try:
