@@ -1,5 +1,5 @@
-# Import python libs
-from git import Repo, Remote
+from git import Remote
+from git import Repo
 
 __virtualname__ = "git"
 
