@@ -1,4 +1,3 @@
-# Import python libs
 import pathlib
 
 
@@ -8,8 +7,8 @@ async def push(hub, ctx, root_path: pathlib.Path):
     """
     ret = await hub.exec.twine.cmd.check(str(root_path / "dist" / "*"))
     if not ret.result:
-        raise RuntimeError("Dist files failed check")
+        raise RuntimeError(f"Dist files failed check:\n{ret.ret}")
 
     ret = await hub.exec.twine.cmd.upload(ctx, str(root_path / "dist" / "*"))
     if not ret.result:
-        raise RuntimeError(f"{ret.comment}: Dist files failed to upload")
+        raise RuntimeError(f"Dist files failed to upload:\n{ret.ret}")
